@@ -4,7 +4,7 @@ import logging
 import subprocess
 from typing import List, NoReturn, Union, Any
 
-from . import node
+from . import __pyright_version__, node
 from .utils import env_to_bool
 
 
@@ -23,8 +23,8 @@ def main(args: List[str], **kwargs: Any) -> int:
 def run(
     *args: str, **kwargs: Any
 ) -> Union['subprocess.CompletedProcess[bytes]', 'subprocess.CompletedProcess[str]']:
-    version = os.environ.get('PYRIGHT_PYTHON_FORCE_VERSION')
-    if version is None:
+    version = os.environ.get('PYRIGHT_PYTHON_FORCE_VERSION', __pyright_version__)
+    if version == 'latest':
         version = node.latest('pyright')
 
     npx = node.version('npx')
@@ -37,7 +37,7 @@ def run(
         pre_args = []
 
     if args and pre_args:
-        args = ('--', *args)
+        pre_args = (*pre_args, '--')
 
     return node.run('npx', *pre_args, f'pyright@{version}', *args, **kwargs)
 
