@@ -1,6 +1,7 @@
 import os
 import sys
 import tempfile
+from getpass import getuser
 from pathlib import Path
 from typing import Union
 
@@ -11,7 +12,12 @@ def get_env_dir() -> Path:
     if env_dir is not None:
         return Path(env_dir)
 
-    return Path(tempfile.gettempdir()) / 'pyright-prisma' / 'env'
+    try:
+        suffix = f'.{getuser()}'
+    except Exception:
+        suffix = ''
+
+    return Path(tempfile.gettempdir()) / f'pyright-python{suffix}' / 'env'
 
 
 def env_to_bool(key: str, *, default: bool = False) -> bool:
